@@ -1,11 +1,13 @@
 from .clips import clips
 from .download import download
+from .env import env
 from .info import info
 from .videos import videos
 
 __all__ = [
     clips,
     download,
+    env,
     info,
     videos,
 ]
